@@ -14,6 +14,7 @@
 #include <glib/gi18n.h>
 #include <gdk/gdkx.h>
 
+#include <libgnome-panel/gp-action-private.h>
 #include <libpanel-util/panel-glib.h>
 #include <libpanel-util/panel-show.h>
 
@@ -23,7 +24,6 @@
 #include "panel-bindings.h"
 #include "panel-applet-frame.h"
 #include "panel-action-button.h"
-#include "panel-menu-bar.h"
 #include "panel-toplevel.h"
 #include "panel-util.h"
 #include "panel-menu-button.h"
@@ -63,7 +63,6 @@ panel_applet_set_dnd_enabled (AppletInfo *info,
 		panel_action_button_set_dnd_enabled (PANEL_ACTION_BUTTON (info->widget),
 						     dnd_enabled);
 		break;
-	case PANEL_OBJECT_MENU_BAR:
 	case PANEL_OBJECT_USER_MENU:
 		break;
 	default:
@@ -179,10 +178,6 @@ applet_callback_callback (GtkWidget      *widget,
 		panel_action_button_invoke_menu (
 			PANEL_ACTION_BUTTON (menu->info->widget), menu->name);
 		break;
-	case PANEL_OBJECT_MENU_BAR:
-		panel_menu_bar_invoke_menu (
-			PANEL_MENU_BAR (menu->info->widget), menu->name);
-		break;
 
 	case PANEL_OBJECT_APPLET:
 		/*
@@ -889,6 +884,34 @@ panel_applet_get_by_type (PanelObjectType object_type, GdkScreen *screen)
 	return NULL;
 }
 
+gboolean
+panel_applet_activate_main_menu (guint32 activate_time)
+{
+  GSList *l;
+
+  for (l = registered_applets; l != NULL; l = l->next)
+    {
+      AppletInfo *info;
+      GtkWidget *applet;
+
+      info = l->data;
+      if (info->type != PANEL_OBJECT_APPLET)
+        continue;
+
+      applet = gtk_bin_get_child (GTK_BIN (info->widget));
+      if (applet == NULL)
+        continue;
+
+      if (!g_type_is_a (G_TYPE_FROM_INSTANCE (applet), GP_TYPE_ACTION))
+        continue;
+
+      if (gp_action_main_menu (GP_ACTION (applet), activate_time))
+        return TRUE;
+    }
+
+  return FALSE;
+}
+
 AppletInfo *
 panel_applet_register (GtkWidget       *applet,
 		       PanelWidget     *panel,
