@@ -39,9 +39,7 @@
 #include "launcher.h"
 #include "panel-action-button.h"
 #include "panel-applet-frame.h"
-#include "panel-menu-bar.h"
 #include "panel-menu-button.h"
-#include "panel-separator.h"
 #include "panel-user-menu.h"
 
 #include "panel-object-loader.h"
@@ -220,16 +218,6 @@ panel_object_loader_idle_handler (gpointer dummy)
                                           object->settings,
                                           object_type_detail);
                 break;
-        case PANEL_OBJECT_MENU_BAR:
-                panel_menu_bar_load (panel_widget,
-                                     object->id,
-                                     object->settings);
-                break;
-        case PANEL_OBJECT_SEPARATOR:
-                panel_separator_load (panel_widget,
-                                      object->id,
-                                      object->settings);
-                break;
         case PANEL_OBJECT_USER_MENU:
                 panel_user_menu_load (panel_widget,
                                       object->id,
@@ -370,10 +358,8 @@ static struct {
         gboolean         has_detail;
 } panel_object_iid_map[] = {
         { PANEL_OBJECT_ACTION,    "ActionButton" , TRUE  },
-        { PANEL_OBJECT_MENU_BAR,  "MenuBar"      , FALSE },
         { PANEL_OBJECT_MENU,      "MenuButton"   , FALSE },
         { PANEL_OBJECT_LAUNCHER,  "Launcher"     , FALSE },
-        { PANEL_OBJECT_SEPARATOR, "Separator"    , FALSE },
         { PANEL_OBJECT_USER_MENU, "UserMenu"     , FALSE }
 };
 
