@@ -32,7 +32,6 @@
 #include "panel-util.h"
 #include "panel-applet-frame.h"
 #include "panel-action-button.h"
-#include "panel-menu-bar.h"
 #include "panel-multiscreen.h"
 #include "panel-toplevel.h"
 #include "panel-menu-button.h"
@@ -82,7 +81,6 @@ orientation_change (AppletInfo  *info,
 	case PANEL_OBJECT_ACTION:
 		button_widget_set_orientation (BUTTON_WIDGET (info->widget), orientation);
 		break;
-	case PANEL_OBJECT_MENU_BAR:
 	case PANEL_OBJECT_USER_MENU:
 		panel_menu_bar_object_set_orientation (PANEL_MENU_BAR_OBJECT (info->widget), orientation);
 		break;
@@ -534,7 +532,7 @@ drop_nautilus_desktop_uri (PanelWidget         *panel,
 		panel_launcher_create_from_info (panel->toplevel,
 						 pack_type, pack_index,
 						 TRUE, /* is_exec? */
-						 "nautilus --no-desktop", /* exec */
+						 "nautilus", /* exec */
 						 name, /* name */
 						 _("Open your personal folder"), /* comment */
 						 PANEL_ICON_HOME); /* icon name */
@@ -544,7 +542,7 @@ drop_nautilus_desktop_uri (PanelWidget         *panel,
 		panel_launcher_create_from_info (panel->toplevel,
 						 pack_type, pack_index,
 						 TRUE, /* is_exec? */
-						 "nautilus --no-desktop computer://", /* exec */
+						 "nautilus computer://", /* exec */
 						 _("Computer"), /* name */
 						 _("Browse all local and remote disks and folders accessible from this computer"), /* comment */
 						 PANEL_ICON_COMPUTER); /* icon name */
@@ -552,7 +550,7 @@ drop_nautilus_desktop_uri (PanelWidget         *panel,
 		panel_launcher_create_from_info (panel->toplevel,
 						 pack_type, pack_index,
 						 TRUE, /* is_exec? */
-						 "nautilus --no-desktop network://", /* exec */
+						 "nautilus network://", /* exec */
 						 _("Network"), /* name */
 						 _("Browse bookmarked and local network locations"), /* comment */
 						 PANEL_ICON_NETWORK); /* icon name */
@@ -697,7 +695,7 @@ drop_urilist (PanelWidget         *panel,
 				success = FALSE;
 		}
 
-		g_object_unref (info);
+		g_clear_object (&info);
 		g_object_unref (file);
 	}
 
@@ -834,15 +832,6 @@ drop_internal_applet (PanelWidget         *panel,
 			success = FALSE;
 		}
 
-	} else if (!strcmp (applet_type, "MENUBAR:NEW")) {
-		if (panel_layout_is_writable ()) {
-			panel_menu_bar_create (panel->toplevel,
-					       pack_type, pack_index);
-			success = TRUE;
-		} else {
-			success = FALSE;
-		}
-
 	} else if (!strcmp (applet_type, "USERMENU:NEW")) {
 		if (panel_layout_is_writable ()) {
 			panel_user_menu_create (panel->toplevel,
